@@ -262,7 +262,8 @@ class Spark2(Hive):
             arg = expression.this
             is_json_extract = isinstance(arg, (exp.JSONExtract, exp.JSONExtractScalar))
 
-            if is_parse_json(arg) or is_json_extract:
+            # We can't use a non-nested type (eg. STRING) as a schema
+            if expression.to.args.get("nested") and (is_parse_json(arg) or is_json_extract):
                 schema = f"'{self.sql(expression, 'to')}'"
                 return self.func("FROM_JSON", arg if is_json_extract else arg.this, schema)
 
@@ -283,4 +284,4 @@ class Spark2(Hive):
             )
 
     class Tokenizer(Hive.Tokenizer):
-        HEX_STRINGS = [("X'", "'")]
+        HEX_STRINGS = [("X'", "'"), ("x'", "'")]
