@@ -10,10 +10,9 @@ from sqlglot.helper import dict_depth, first
 from sqlglot.trie import TrieResult, in_trie, new_trie
 
 if t.TYPE_CHECKING:
-    from sqlglot.dataframe.sql.types import StructType
     from sqlglot.dialects.dialect import DialectType
 
-    ColumnMapping = t.Union[t.Dict, str, StructType, t.List]
+    ColumnMapping = t.Union[t.Dict, str, t.List]
 
 
 class Schema(abc.ABC):
@@ -156,13 +155,16 @@ class AbstractMappingSchema:
             return [table.this.name]
         return [table.text(part) for part in exp.TABLE_PARTS if table.text(part)]
 
-    def find(self, table: exp.Table, raise_on_missing: bool = True) -> t.Optional[t.Any]:
+    def find(
+        self, table: exp.Table, raise_on_missing: bool = True, ensure_data_types: bool = False
+    ) -> t.Optional[t.Any]:
         """
         Returns the schema of a given table.
 
         Args:
             table: the target table.
             raise_on_missing: whether to raise in case the schema is not found.
+            ensure_data_types: whether to convert `str` types to their `DataType` equivalents.
 
         Returns:
             The schema of the target table.
@@ -240,6 +242,20 @@ class MappingSchema(AbstractMappingSchema, Schema):
             normalize=mapping_schema.normalize,
         )
 
+    def find(
+        self, table: exp.Table, raise_on_missing: bool = True, ensure_data_types: bool = False
+    ) -> t.Optional[t.Any]:
+        schema = super().find(
+            table, raise_on_missing=raise_on_missing, ensure_data_types=ensure_data_types
+        )
+        if ensure_data_types and isinstance(schema, dict):
+            schema = {
+                col: self._to_data_type(dtype) if isinstance(dtype, str) else dtype
+                for col, dtype in schema.items()
+            }
+
+        return schema
+
     def copy(self, **kwargs) -> MappingSchema:
         return MappingSchema(
             **{  # type: ignore
@@ -489,9 +505,6 @@ def ensure_column_mapping(mapping: t.Optional[ColumnMapping]) -> t.Dict:
             name_type_str.split(":")[0].strip(): name_type_str.split(":")[1].strip()
             for name_type_str in col_name_type_strs
         }
-    # Check if mapping looks like a DataFrame StructType
-    elif hasattr(mapping, "simpleString"):
-        return {struct_field.name: struct_field.dataType.simpleString() for struct_field in mapping}
     elif isinstance(mapping, list):
         return {x.strip(): None for x in mapping}
 
